==> angelscript_2.27.0.zip: sdk/docs/manual/doc_addon_script.js <==
var doc_addon_script =
[
    [ "string object", "doc_addon_std_string.html", [
      [ "Public C++ interface", "doc_addon_std_string.html#doc_addon_std_string_1", null ],
      [ "Public script interface", "doc_addon_std_string.html#doc_addon_std_string_2", null ]
    ] ],
    [ "array template object", "doc_addon_array.html", [
      [ "Public C++ interface", "doc_addon_array.html#doc_addon_array_1", null ],
      [ "Public script interface", "doc_addon_array.html#doc_addon_array_2", null ],
      [ "C++ example", "doc_addon_array.html#doc_addon_array_4", null ]
    ] ],
    [ "any object", "doc_addon_any.html", [
      [ "Public C++ interface", "doc_addon_any.html#doc_addon_any_1", null ],
      [ "Public script interface", "doc_addon_any.html#doc_addon_any_2", null ],
      [ "Example usage", "doc_addon_any.html#doc_addon_any_3", null ]
    ] ],
    [ "ref object", "doc_addon_handle.html", [
      [ "Public C++ interface", "doc_addon_handle.html#doc_addon_handle_1", null ],
      [ "Example usage in script", "doc_addon_handle.html#doc_addon_handle_3", null ],
      [ "Example usage from C++", "doc_addon_handle.html#doc_addon_handle_4", null ]
    ] ],
    [ "weakref object", "doc_addon_weakref.html", [
      [ "Public C++ interface", "doc_addon_weakref.html#doc_addon_weakref_1", null ],
      [ "Example usage in script", "doc_addon_weakref.html#doc_addon_weakref_2", null ]
    ] ],
    [ "dictionary object", "doc_addon_dict.html", [
      [ "Public C++ interface", "doc_addon_dict.html#doc_addon_dict_1", null ],
      [ "Public script interface", "doc_addon_dict.html#doc_addon_dict_2", null ],
      [ "Script example", "doc_addon_dict.html#doc_addon_dict_3", null ]
    ] ],
    [ "file object", "doc_addon_file.html", [
      [ "Public C++ interface", "doc_addon_file.html#doc_addon_file_1", null ],
      [ "Public script interface", "doc_addon_file.html#doc_addon_file_2", null ],
      [ "Script example", "doc_addon_file.html#doc_addon_file_3", null ]
    ] ],
    [ "math functions", "doc_addon_math.html", [
      [ "Public script interface", "doc_addon_math.html#doc_addon_math_1", null ]
    ] ]
];

==> angelscript_2.31.2.zip: sdk/docs/manual/doc_addon_script.js <==
var doc_addon_script =
[
    [ "string object", "doc_addon_std_string.html", [
      [ "Public C++ interface", "doc_addon_std_string.html#doc_addon_std_string_1", null ],
      [ "Public script interface", "doc_addon_std_string.html#doc_addon_std_string_2", null ]
    ] ],
    [ "array template object", "doc_addon_array.html", [
      [ "Public C++ interface", "doc_addon_array.html#doc_addon_array_1", null ],
      [ "Public script interface", "doc_addon_array.html#doc_addon_array_2", null ],
      [ "C++ example", "doc_addon_array.html#doc_addon_array_4", null ]
    ] ],
    [ "any object", "doc_addon_any.html", [
      [ "Public C++ interface", "doc_addon_any.html#doc_addon_any_1", null ],
      [ "Public script interface", "doc_addon_any.html#doc_addon_any_2", null ],
      [ "Example usage", "doc_addon_any.html#doc_addon_any_3", null ]
    ] ],
    [ "ref object", "doc_addon_handle.html", [
      [ "Public C++ interface", "doc_addon_handle.html#doc_addon_handle_1", null ],
      [ "Public script interface", "doc_addon_handle.html#doc_addon_handle_3", null ],
      [ "Example usage from C++", "doc_addon_handle.html#doc_addon_handle_4", null ]
    ] ],
    [ "weakref object", "doc_addon_weakref.html", [
      [ "Public C++ interface", "doc_addon_weakref.html#doc_addon_weakref_1", null ],
      [ "Public script interface", "doc_addon_weakref.html#doc_addon_weakref_2", null ]
    ] ],
    [ "dictionary object", "doc_addon_dict.html", [
      [ "Public C++ interface", "doc_addon_dict.html#doc_addon_dict_1", null ],
      [ "Public script interface", "doc_addon_dict.html#doc_addon_dict_2", null ]
    ] ],
    [ "file object", "doc_addon_file.html", [
      [ "Public C++ interface", "doc_addon_file.html#doc_addon_file_1", null ],
      [ "Public script interface", "doc_addon_file.html#doc_addon_file_2", null ],
      [ "Script example", "doc_addon_file.html#doc_addon_file_3", null ]
    ] ],
    [ "filesystem object", "doc_addon_filesystem.html", [
      [ "Public C++ interface", "doc_addon_filesystem.html#doc_addon_filesystem_1", null ],
      [ "Public script interface", "doc_addon_filesystem.html#doc_addon_filesystem_2", null ]
    ] ],
    [ "math functions", "doc_addon_math.html", [
      [ "Public script interface", "doc_addon_math.html#doc_addon_math_1", null ]
    ] ],
    [ "grid template object", "doc_addon_grid.html", [
      [ "Public C++ interface", "doc_addon_grid.html#doc_addon_grid_1", null ],
      [ "Public script interface", "doc_addon_grid.html#doc_addon_grid_2", null ],
      [ "Example usage in script", "doc_addon_grid.html#doc_addon_grid_3", null ]
    ] ],
    [ "datetime object", "doc_addon_datetime.html", [
      [ "Public C++ interface", "doc_addon_datetime.html#doc_addon_array_1", null ],
      [ "Public script interface", "doc_addon_datetime.html#doc_addon_array_2", null ]
    ] ]
];
